pub trait Spawn { }Expand description
Implemented by different types that can be spawned and snapshotted.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Spawn { }Implemented by different types that can be spawned and snapshotted.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".